[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/binchicken/README.html)
[![DOI](https://zenodo.org/badge/531785064.svg)](https://zenodo.org/doi/10.5281/zenodo.10511708)
![](https://anaconda.org/bioconda/binchicken/badges/version.svg)
![](https://anaconda.org/bioconda/binchicken/badges/latest_release_relative_date.svg)
![](https://anaconda.org/bioconda/binchicken/badges/license.svg)
![](https://anaconda.org/bioconda/binchicken/badges/platforms.svg)

# Bin Chicken

[<img src="docs/_include/binchicken_logo.png" width="50%" />](binchicken_logo.png)

Bin Chicken - recovery of low abundance and taxonomically targeted metagenome assembled genomes (MAGs) through strategic coassembly.

Documentation can be found at https://AroneyS.github.io/binchicken/

Logo by Georgina H. Joyce | www.georginajoyce.com

Not to be confused with https://gitlab.com/andreassh/binchicken

## Citation

Samuel T. N. Aroney, Rhys J. P. Newell, Gene W. Tyson and Ben J. Woodcroft.
Bin Chicken: targeted metagenomic coassembly for the efficient recovery of novel genomes.
bioRxiv (2024): 2024-11. https://doi.org/10.1101/2024.11.24.625082
